.onAttach <-
function (libname, pkgname){
   # echo output to screen
   packageStartupMessage("## Since v.1.3.0, *gsynth* is a wrapper of the *fect* package.")
   packageStartupMessage("## Comments and suggestions -> yiqingxu@stanford.edu.")
}
